@@ -176,16 +176,25 @@ public class FromXmlParser
 
     public FromXmlParser(IOContext ctxt, int genericParserFeatures, int xmlFeatures,
             ObjectCodec codec, XMLStreamReader xmlReader)
+        throws IOException
     {
         super(genericParserFeatures);
         _formatFeatures = xmlFeatures;
         _ioContext = ctxt;
         _objectCodec = codec;
         _parsingContext = XmlReadContext.createRootContext(-1, -1);
-        // and thereby start a scope
-        _nextToken = JsonToken.START_OBJECT;
         _xmlTokens = new XmlTokenStream(xmlReader, ctxt.getSourceReference(),
                 _formatFeatures);
+
+        // 04-Jan-2019, tatu: Root-level nulls need slightly specific handling;
+        //    changed in 2.10.2
+        if (_xmlTokens.hasXsiNil()) {
+            _nextToken = JsonToken.VALUE_NULL;
+        } else if (_xmlTokens.getCurrentToken() == XmlTokenStream.XML_START_ELEMENT) {
+            _nextToken = JsonToken.START_OBJECT;
+        } else {
+            _reportError("Internal problem: invalid starting state (%d)", _xmlTokens.getCurrentToken());
+        }
     }
 
     @Override
@@ -462,11 +471,9 @@ public class FromXmlParser
         }
         return t;
     }
+    */
 
 //    public JsonToken nextToken0() throws IOException
- */
-
-    
     @Override
     public JsonToken nextToken() throws IOException
     {
@@ -551,13 +558,16 @@ public class FromXmlParser
                         _parsingContext = _parsingContext.createChildObjectContext(-1, -1);
                         return (_currToken = JsonToken.START_OBJECT);
                     }
-                    return (_currToken = JsonToken.VALUE_NULL);
+                    // 07-Sep-2019, tatu: for [dataformat-xml#353], must NOT return second null
+                    if (_currToken != JsonToken.VALUE_NULL) {
+                        return (_currToken = JsonToken.VALUE_NULL);
+                    }
                 }
                 _currToken = _parsingContext.inArray() ? JsonToken.END_ARRAY : JsonToken.END_OBJECT;
                 _parsingContext = _parsingContext.getParent();
                 _namesToWrap = _parsingContext.getNamesToWrap();
                 return _currToken;
-                
+
             case XmlTokenStream.XML_ATTRIBUTE_NAME:
                 // If there was a chance of leaf node, no more...
                 if (_mayBeLeaf) {
@@ -596,19 +606,18 @@ public class FromXmlParser
                         }
                     }
                     return (_currToken = JsonToken.VALUE_STRING);
-                } else {
-                    // [dataformat-xml#177]: empty text may also need to be skipped
-                    // but... [dataformat-xml#191]: looks like we can't short-cut, must
-                    // loop over again
-                    if (_parsingContext.inObject()) {
-                        if ((_currToken != JsonToken.FIELD_NAME) && _isEmpty(_currText)) {
-                            try {
-                                token = _xmlTokens.next();
-                            } catch (XMLStreamException e) {
-                                StaxUtil.throwAsParseException(e, this);
-                            }
-                            continue;
+                }
+                // [dataformat-xml#177]: empty text may also need to be skipped
+                // but... [dataformat-xml#191]: looks like we can't short-cut, must
+                // loop over again
+                if (_parsingContext.inObject()) {
+                    if ((_currToken != JsonToken.FIELD_NAME) && _isEmpty(_currText)) {
+                        try {
+                            token = _xmlTokens.next();
+                        } catch (XMLStreamException e) {
+                            StaxUtil.throwAsParseException(e, this);
                         }
+                        continue;
                     }
                 }
                 // If not a leaf (or otherwise ignorable), need to transform into property...
@@ -617,6 +626,8 @@ public class FromXmlParser
                 return (_currToken = JsonToken.FIELD_NAME);
             case XmlTokenStream.XML_END:
                 return (_currToken = null);
+            default:
+                return _internalErrorUnknownToken(token);
             }
         }
     }
@@ -627,6 +638,16 @@ public class FromXmlParser
     /**********************************************************
      */
 
+    /*
+    @Override
+    public String nextFieldName() throws IOException {
+        if (nextToken() == JsonToken.FIELD_NAME) {
+            return getCurrentName();
+        }
+        return null;
+    }
+    */
+
     /**
      * Method overridden to support more reliable deserialization of
      * String collections.
@@ -734,6 +755,8 @@ public class FromXmlParser
             break;
         case XmlTokenStream.XML_END:
             _currToken = null;
+        default:
+            return _internalErrorUnknownToken(token);
         }
         return null;
     }
@@ -757,6 +780,7 @@ public class FromXmlParser
             _parsingContext.setCurrentName(_xmlTokens.getLocalName());
             break;
         default:
+            _internalErrorUnknownToken(t);
         }
     }
 
@@ -1027,4 +1051,8 @@ public class FromXmlParser
         }
         return true;
     }
+
+    private <T> T  _internalErrorUnknownToken(Object token) {
+        throw new IllegalStateException("Internal error: unrecognized XmlTokenStream token: "+token);
+    }
 }
