@@ -56,7 +56,21 @@ public final class ToXmlGenerator
          * control characters (Ascii codes 0 through 31) as well as additional linefeeds
          * and name characters.
          */
-        WRITE_XML_1_1(false)
+        WRITE_XML_1_1(false),
+
+        /**
+         * Feature that controls whether serialization of Java {@code null} values adds
+         * XML attribute of `xsi:nil`, as defined by XML Schema (see
+         * <a href="https://www.oreilly.com/library/view/xml-in-a/0596007647/re166.html">this article</a>
+         * for details) or not.
+         * If enabled, `xsi:nil` attribute will be added to the empty element; if disabled,
+         * it will not.
+         *<p>
+         * Feature is disabled by default for backwards compatibility.
+         *
+         * @since 2.10
+         */
+        WRITE_NULLS_AS_XSI_NIL(false)
         ;
 
         final boolean _defaultState;
@@ -588,7 +602,7 @@ public final class ToXmlGenerator
             if (_nextIsAttribute) { // must write attribute name and value with one call
                 _xmlWriter.writeAttribute(_nextName.getNamespaceURI(), _nextName.getLocalPart(), text);
             } else if (checkNextIsUnwrapped()) {
-                // [Issue#56] Should figure out how to prevent indentation for end element
+                // [dataformat-xml#56] Should figure out how to prevent indentation for end element
                 //   but for now, let's just make sure structure is correct
                 //if (_xmlPrettyPrinter != null) { ... }
                 if(_nextIsCData) {
@@ -1135,9 +1149,15 @@ public final class ToXmlGenerator
                 }
             } else {
                 if (_xmlPrettyPrinter != null) {
-                	_xmlPrettyPrinter.writeLeafElement(_xmlWriter,
-                			_nextName.getNamespaceURI(), _nextName.getLocalPart(),
-                			dec);
+                    if (usePlain) {
+                        _xmlPrettyPrinter.writeLeafElement(_xmlWriter,
+                                _nextName.getNamespaceURI(), _nextName.getLocalPart(),
+                                dec.toPlainString(), false);
+                    } else {
+                        _xmlPrettyPrinter.writeLeafElement(_xmlWriter,
+                                _nextName.getNamespaceURI(), _nextName.getLocalPart(),
+                                dec);
+                    }
                 } else {
 	                _xmlWriter.writeStartElement(_nextName.getNamespaceURI(), _nextName.getLocalPart());
 	                if (usePlain) {
